# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/raw_logs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/raw_logs.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/cdn/v1/raw_logs.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1dyandex/cloud/validation.proto\"v\n\x0fRawLogsSettings\x12#\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1f\n\rbucket_region\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x0b\x66ile_prefix\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50*\x87\x01\n\rRawLogsStatus\x12\x1f\n\x1bRAW_LOGS_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dRAW_LOGS_STATUS_NOT_ACTIVATED\x10\x01\x12\x16\n\x12RAW_LOGS_STATUS_OK\x10\x02\x12\x1a\n\x16RAW_LOGS_STATUS_FAILED\x10\x03\x42V\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_RAWLOGSSTATUS = _descriptor.EnumDescriptor(
  name='RawLogsStatus',
  full_name='yandex.cloud.cdn.v1.RawLogsStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW_LOGS_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_LOGS_STATUS_NOT_ACTIVATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_LOGS_STATUS_OK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_LOGS_STATUS_FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=211,
  serialized_end=346,
)
_sym_db.RegisterEnumDescriptor(_RAWLOGSSTATUS)

RawLogsStatus = enum_type_wrapper.EnumTypeWrapper(_RAWLOGSSTATUS)
RAW_LOGS_STATUS_UNSPECIFIED = 0
RAW_LOGS_STATUS_NOT_ACTIVATED = 1
RAW_LOGS_STATUS_OK = 2
RAW_LOGS_STATUS_FAILED = 3



_RAWLOGSSETTINGS = _descriptor.Descriptor(
  name='RawLogsSettings',
  full_name='yandex.cloud.cdn.v1.RawLogsSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_name', full_name='yandex.cloud.cdn.v1.RawLogsSettings.bucket_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_region', full_name='yandex.cloud.cdn.v1.RawLogsSettings.bucket_region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_prefix', full_name='yandex.cloud.cdn.v1.RawLogsSettings.file_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=208,
)

DESCRIPTOR.message_types_by_name['RawLogsSettings'] = _RAWLOGSSETTINGS
DESCRIPTOR.enum_types_by_name['RawLogsStatus'] = _RAWLOGSSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RawLogsSettings = _reflection.GeneratedProtocolMessageType('RawLogsSettings', (_message.Message,), {
  'DESCRIPTOR' : _RAWLOGSSETTINGS,
  '__module__' : 'yandex.cloud.cdn.v1.raw_logs_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.RawLogsSettings)
  })
_sym_db.RegisterMessage(RawLogsSettings)


DESCRIPTOR._options = None
_RAWLOGSSETTINGS.fields_by_name['bucket_name']._options = None
_RAWLOGSSETTINGS.fields_by_name['bucket_region']._options = None
_RAWLOGSSETTINGS.fields_by_name['file_prefix']._options = None
# @@protoc_insertion_point(module_scope)
