# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/quota/quota.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/quota/quota.proto',
  package='yandex.cloud.quota',
  syntax='proto3',
  serialized_options=b'\n\026yandex.cloud.api.quotaZ<github.com/yandex-cloud/go-genproto/yandex/cloud/quota;quota',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eyandex/cloud/quota/quota.proto\x12\x12yandex.cloud.quota\"9\n\x0bQuotaMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x03\x12\r\n\x05usage\x18\x04 \x01(\x01\"*\n\x0bMetricLimit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x03\"\x9e\x01\n\x0cQuotaFailure\x12>\n\nviolations\x18\x02 \x03(\x0b\x32*.yandex.cloud.quota.QuotaFailure.Violation\x1aN\n\tViolation\x12/\n\x06metric\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.quota.QuotaMetric\x12\x10\n\x08required\x18\x02 \x01(\x03\x42V\n\x16yandex.cloud.api.quotaZ<github.com/yandex-cloud/go-genproto/yandex/cloud/quota;quotab\x06proto3'
)




_QUOTAMETRIC = _descriptor.Descriptor(
  name='QuotaMetric',
  full_name='yandex.cloud.quota.QuotaMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.quota.QuotaMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yandex.cloud.quota.QuotaMetric.limit', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='yandex.cloud.quota.QuotaMetric.usage', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=111,
)


_METRICLIMIT = _descriptor.Descriptor(
  name='MetricLimit',
  full_name='yandex.cloud.quota.MetricLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.quota.MetricLimit.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yandex.cloud.quota.MetricLimit.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=155,
)


_QUOTAFAILURE_VIOLATION = _descriptor.Descriptor(
  name='Violation',
  full_name='yandex.cloud.quota.QuotaFailure.Violation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric', full_name='yandex.cloud.quota.QuotaFailure.Violation.metric', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='yandex.cloud.quota.QuotaFailure.Violation.required', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=316,
)

_QUOTAFAILURE = _descriptor.Descriptor(
  name='QuotaFailure',
  full_name='yandex.cloud.quota.QuotaFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='violations', full_name='yandex.cloud.quota.QuotaFailure.violations', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUOTAFAILURE_VIOLATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=316,
)

_QUOTAFAILURE_VIOLATION.fields_by_name['metric'].message_type = _QUOTAMETRIC
_QUOTAFAILURE_VIOLATION.containing_type = _QUOTAFAILURE
_QUOTAFAILURE.fields_by_name['violations'].message_type = _QUOTAFAILURE_VIOLATION
DESCRIPTOR.message_types_by_name['QuotaMetric'] = _QUOTAMETRIC
DESCRIPTOR.message_types_by_name['MetricLimit'] = _METRICLIMIT
DESCRIPTOR.message_types_by_name['QuotaFailure'] = _QUOTAFAILURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuotaMetric = _reflection.GeneratedProtocolMessageType('QuotaMetric', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAMETRIC,
  '__module__' : 'yandex.cloud.quota.quota_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.quota.QuotaMetric)
  })
_sym_db.RegisterMessage(QuotaMetric)

MetricLimit = _reflection.GeneratedProtocolMessageType('MetricLimit', (_message.Message,), {
  'DESCRIPTOR' : _METRICLIMIT,
  '__module__' : 'yandex.cloud.quota.quota_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.quota.MetricLimit)
  })
_sym_db.RegisterMessage(MetricLimit)

QuotaFailure = _reflection.GeneratedProtocolMessageType('QuotaFailure', (_message.Message,), {

  'Violation' : _reflection.GeneratedProtocolMessageType('Violation', (_message.Message,), {
    'DESCRIPTOR' : _QUOTAFAILURE_VIOLATION,
    '__module__' : 'yandex.cloud.quota.quota_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.quota.QuotaFailure.Violation)
    })
  ,
  'DESCRIPTOR' : _QUOTAFAILURE,
  '__module__' : 'yandex.cloud.quota.quota_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.quota.QuotaFailure)
  })
_sym_db.RegisterMessage(QuotaFailure)
_sym_db.RegisterMessage(QuotaFailure.Violation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
