# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/kafka/v1/connector.proto',
  package='yandex.cloud.mdb.kafka.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/mdb/kafka/v1/connector.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xc5\x02\n\rConnectorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\nproperties\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_config\"\xc3\x02\n\x13UpdateConnectorSpec\x12.\n\ttasks_max\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n\nproperties\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_config\"\xfd\x01\n\x1e\x43onnectorConfigMirrorMakerSpec\x12H\n\x0esource_cluster\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12H\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd6\x01\n\x15\x43lusterConnectionSpec\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12\x42\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.kafka.v1.ThisClusterSpecH\x00\x12T\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpecH\x00\x42\x14\n\x12\x63luster_connection\"\x11\n\x0fThisClusterSpec\"\xc0\x01\n\x1d\x45xternalClusterConnectionSpec\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x15\n\rsasl_password\x18\x03 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\t\x12#\n\x1bssl_truststore_certificates\x18\x06 \x01(\t\"\xbc\x04\n\tConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n\nproperties\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry\x12;\n\x06health\x18\x04 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Health\x12;\n\x06status\x18\x05 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Status\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12]\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x35.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"@\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\n\n\x06PAUSED\x10\x03\x42\x12\n\x10\x63onnector_config\"\xf1\x01\n\x1a\x43onnectorConfigMirrorMaker\x12\x44\n\x0esource_cluster\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x44\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xca\x01\n\x11\x43lusterConnection\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12>\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.kafka.v1.ThisClusterH\x00\x12P\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionH\x00\x42\x14\n\x12\x63luster_connection\"\r\n\x0bThisCluster\"\x80\x01\n\x19\x45xternalClusterConnection\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\tBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_CONNECTOR_HEALTH = _descriptor.EnumDescriptor(
  name='Health',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.Health',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEALTH_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1883,
  serialized_end=1932,
)
_sym_db.RegisterEnumDescriptor(_CONNECTOR_HEALTH)

_CONNECTOR_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1934,
  serialized_end=1998,
)
_sym_db.RegisterEnumDescriptor(_CONNECTOR_STATUS)


_CONNECTORSPEC_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_CONNECTORSPEC = _descriptor.Descriptor(
  name='ConnectorSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.tasks_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.connector_config_mirrormaker', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTORSPEC_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105,
  serialized_end=430,
)


_UPDATECONNECTORSPEC_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_UPDATECONNECTORSPEC = _descriptor.Descriptor(
  name='UpdateConnectorSpec',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.tasks_max', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.connector_config_mirrormaker', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECONNECTORSPEC_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=433,
  serialized_end=756,
)


_CONNECTORCONFIGMIRRORMAKERSPEC = _descriptor.Descriptor(
  name='ConnectorConfigMirrorMakerSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.source_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.target_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.topics', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.replication_factor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1012,
)


_CLUSTERCONNECTIONSPEC = _descriptor.Descriptor(
  name='ClusterConnectionSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alias', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='this_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.this_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.external_cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_connection', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.cluster_connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1015,
  serialized_end=1229,
)


_THISCLUSTERSPEC = _descriptor.Descriptor(
  name='ThisClusterSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ThisClusterSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1248,
)


_EXTERNALCLUSTERCONNECTIONSPEC = _descriptor.Descriptor(
  name='ExternalClusterConnectionSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap_servers', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.bootstrap_servers', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_username', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_password', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_mechanism', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_mechanism', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_protocol', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.security_protocol', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_truststore_certificates', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.ssl_truststore_certificates', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1443,
)


_CONNECTOR_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_CONNECTOR = _descriptor.Descriptor(
  name='Connector',
  full_name='yandex.cloud.mdb.kafka.v1.Connector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.Connector.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.Connector.tasks_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.Connector.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='yandex.cloud.mdb.kafka.v1.Connector.health', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.mdb.kafka.v1.Connector.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.Connector.cluster_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.Connector.connector_config_mirrormaker', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTOR_PROPERTIESENTRY, ],
  enum_types=[
    _CONNECTOR_HEALTH,
    _CONNECTOR_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.Connector.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1446,
  serialized_end=2018,
)


_CONNECTORCONFIGMIRRORMAKER = _descriptor.Descriptor(
  name='ConnectorConfigMirrorMaker',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.source_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.target_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.topics', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.replication_factor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2262,
)


_CLUSTERCONNECTION = _descriptor.Descriptor(
  name='ClusterConnection',
  full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alias', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='this_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.this_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.external_cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_connection', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.cluster_connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2265,
  serialized_end=2467,
)


_THISCLUSTER = _descriptor.Descriptor(
  name='ThisCluster',
  full_name='yandex.cloud.mdb.kafka.v1.ThisCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2469,
  serialized_end=2482,
)


_EXTERNALCLUSTERCONNECTION = _descriptor.Descriptor(
  name='ExternalClusterConnection',
  full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap_servers', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.bootstrap_servers', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_username', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.sasl_username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_mechanism', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.sasl_mechanism', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_protocol', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.security_protocol', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2613,
)

_CONNECTORSPEC_PROPERTIESENTRY.containing_type = _CONNECTORSPEC
_CONNECTORSPEC.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTORSPEC.fields_by_name['properties'].message_type = _CONNECTORSPEC_PROPERTIESENTRY
_CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKERSPEC
_CONNECTORSPEC.oneofs_by_name['connector_config'].fields.append(
  _CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'])
_CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].containing_oneof = _CONNECTORSPEC.oneofs_by_name['connector_config']
_UPDATECONNECTORSPEC_PROPERTIESENTRY.containing_type = _UPDATECONNECTORSPEC
_UPDATECONNECTORSPEC.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_UPDATECONNECTORSPEC.fields_by_name['properties'].message_type = _UPDATECONNECTORSPEC_PROPERTIESENTRY
_UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKERSPEC
_UPDATECONNECTORSPEC.oneofs_by_name['connector_config'].fields.append(
  _UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'])
_UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].containing_oneof = _UPDATECONNECTORSPEC.oneofs_by_name['connector_config']
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['source_cluster'].message_type = _CLUSTERCONNECTIONSPEC
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['target_cluster'].message_type = _CLUSTERCONNECTIONSPEC
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'].message_type = _THISCLUSTERSPEC
_CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'].message_type = _EXTERNALCLUSTERCONNECTIONSPEC
_CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'])
_CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'].containing_oneof = _CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection']
_CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'])
_CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'].containing_oneof = _CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection']
_CONNECTOR_PROPERTIESENTRY.containing_type = _CONNECTOR
_CONNECTOR.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTOR.fields_by_name['properties'].message_type = _CONNECTOR_PROPERTIESENTRY
_CONNECTOR.fields_by_name['health'].enum_type = _CONNECTOR_HEALTH
_CONNECTOR.fields_by_name['status'].enum_type = _CONNECTOR_STATUS
_CONNECTOR.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKER
_CONNECTOR_HEALTH.containing_type = _CONNECTOR
_CONNECTOR_STATUS.containing_type = _CONNECTOR
_CONNECTOR.oneofs_by_name['connector_config'].fields.append(
  _CONNECTOR.fields_by_name['connector_config_mirrormaker'])
_CONNECTOR.fields_by_name['connector_config_mirrormaker'].containing_oneof = _CONNECTOR.oneofs_by_name['connector_config']
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['source_cluster'].message_type = _CLUSTERCONNECTION
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['target_cluster'].message_type = _CLUSTERCONNECTION
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CLUSTERCONNECTION.fields_by_name['this_cluster'].message_type = _THISCLUSTER
_CLUSTERCONNECTION.fields_by_name['external_cluster'].message_type = _EXTERNALCLUSTERCONNECTION
_CLUSTERCONNECTION.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTION.fields_by_name['this_cluster'])
_CLUSTERCONNECTION.fields_by_name['this_cluster'].containing_oneof = _CLUSTERCONNECTION.oneofs_by_name['cluster_connection']
_CLUSTERCONNECTION.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTION.fields_by_name['external_cluster'])
_CLUSTERCONNECTION.fields_by_name['external_cluster'].containing_oneof = _CLUSTERCONNECTION.oneofs_by_name['cluster_connection']
DESCRIPTOR.message_types_by_name['ConnectorSpec'] = _CONNECTORSPEC
DESCRIPTOR.message_types_by_name['UpdateConnectorSpec'] = _UPDATECONNECTORSPEC
DESCRIPTOR.message_types_by_name['ConnectorConfigMirrorMakerSpec'] = _CONNECTORCONFIGMIRRORMAKERSPEC
DESCRIPTOR.message_types_by_name['ClusterConnectionSpec'] = _CLUSTERCONNECTIONSPEC
DESCRIPTOR.message_types_by_name['ThisClusterSpec'] = _THISCLUSTERSPEC
DESCRIPTOR.message_types_by_name['ExternalClusterConnectionSpec'] = _EXTERNALCLUSTERCONNECTIONSPEC
DESCRIPTOR.message_types_by_name['Connector'] = _CONNECTOR
DESCRIPTOR.message_types_by_name['ConnectorConfigMirrorMaker'] = _CONNECTORCONFIGMIRRORMAKER
DESCRIPTOR.message_types_by_name['ClusterConnection'] = _CLUSTERCONNECTION
DESCRIPTOR.message_types_by_name['ThisCluster'] = _THISCLUSTER
DESCRIPTOR.message_types_by_name['ExternalClusterConnection'] = _EXTERNALCLUSTERCONNECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectorSpec = _reflection.GeneratedProtocolMessageType('ConnectorSpec', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTORSPEC_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CONNECTORSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorSpec)
  })
_sym_db.RegisterMessage(ConnectorSpec)
_sym_db.RegisterMessage(ConnectorSpec.PropertiesEntry)

UpdateConnectorSpec = _reflection.GeneratedProtocolMessageType('UpdateConnectorSpec', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONNECTORSPEC_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONNECTORSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec)
  })
_sym_db.RegisterMessage(UpdateConnectorSpec)
_sym_db.RegisterMessage(UpdateConnectorSpec.PropertiesEntry)

ConnectorConfigMirrorMakerSpec = _reflection.GeneratedProtocolMessageType('ConnectorConfigMirrorMakerSpec', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCONFIGMIRRORMAKERSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec)
  })
_sym_db.RegisterMessage(ConnectorConfigMirrorMakerSpec)

ClusterConnectionSpec = _reflection.GeneratedProtocolMessageType('ClusterConnectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONNECTIONSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec)
  })
_sym_db.RegisterMessage(ClusterConnectionSpec)

ThisClusterSpec = _reflection.GeneratedProtocolMessageType('ThisClusterSpec', (_message.Message,), {
  'DESCRIPTOR' : _THISCLUSTERSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ThisClusterSpec)
  })
_sym_db.RegisterMessage(ThisClusterSpec)

ExternalClusterConnectionSpec = _reflection.GeneratedProtocolMessageType('ExternalClusterConnectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALCLUSTERCONNECTIONSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec)
  })
_sym_db.RegisterMessage(ExternalClusterConnectionSpec)

Connector = _reflection.GeneratedProtocolMessageType('Connector', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTOR_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CONNECTOR,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.Connector)
  })
_sym_db.RegisterMessage(Connector)
_sym_db.RegisterMessage(Connector.PropertiesEntry)

ConnectorConfigMirrorMaker = _reflection.GeneratedProtocolMessageType('ConnectorConfigMirrorMaker', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCONFIGMIRRORMAKER,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker)
  })
_sym_db.RegisterMessage(ConnectorConfigMirrorMaker)

ClusterConnection = _reflection.GeneratedProtocolMessageType('ClusterConnection', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONNECTION,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ClusterConnection)
  })
_sym_db.RegisterMessage(ClusterConnection)

ThisCluster = _reflection.GeneratedProtocolMessageType('ThisCluster', (_message.Message,), {
  'DESCRIPTOR' : _THISCLUSTER,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ThisCluster)
  })
_sym_db.RegisterMessage(ThisCluster)

ExternalClusterConnection = _reflection.GeneratedProtocolMessageType('ExternalClusterConnection', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALCLUSTERCONNECTION,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ExternalClusterConnection)
  })
_sym_db.RegisterMessage(ExternalClusterConnection)


DESCRIPTOR._options = None
_CONNECTORSPEC_PROPERTIESENTRY._options = None
_UPDATECONNECTORSPEC_PROPERTIESENTRY._options = None
_CONNECTOR_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
