# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/disk_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/disk_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/compute/v1/disk_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x10ListDisksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"Z\n\x11ListDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x04\n\x11\x43reateDiskRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x19\n\x07type_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04size\x18\x07 \x01(\x03\x42\x1e\xe8\xc7\x31\x01\xfa\xc7\x31\x16\x34\x31\x39\x34\x33\x30\x34-28587302322176\x12\x1c\n\x08image_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x12\n\nblock_size\x18\n \x01(\x03\x12K\n\x15\x64isk_placement_policy\x18\x0b \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"%\n\x12\x43reateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"\xee\x03\n\x11UpdateDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\'\n\x04size\x18\x06 \x01(\x03\x42\x19\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12K\n\x15\x64isk_placement_policy\x18\x07 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12UpdateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"%\n\x12\x44\x65leteDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"x\n\x19ListDiskOperationsRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x1aListDiskOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"]\n\x0fMoveDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x10MoveDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t2\xaa\x08\n\x0b\x44iskService\x12r\n\x03Get\x12\'.yandex.cloud.compute.v1.GetDiskRequest\x1a\x1d.yandex.cloud.compute.v1.Disk\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/disks/{disk_id}\x12x\n\x04List\x12).yandex.cloud.compute.v1.ListDisksRequest\x1a*.yandex.cloud.compute.v1.ListDisksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/compute/v1/disks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.compute.v1.CreateDiskRequest\x1a!.yandex.cloud.operation.Operation\":\x82\xd3\xe4\x93\x02\x16\"\x11/compute/v1/disks:\x01*\xb2\xd2*\x1a\n\x12\x43reateDiskMetadata\x12\x04\x44isk\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.compute.v1.UpdateDiskRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02 2\x1b/compute/v1/disks/{disk_id}:\x01*\xb2\xd2*\x1a\n\x12UpdateDiskMetadata\x12\x04\x44isk\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.compute.v1.DeleteDiskRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02\x1d*\x1b/compute/v1/disks/{disk_id}\xb2\xd2*+\n\x12\x44\x65leteDiskMetadata\x12\x15google.protobuf.Empty\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.compute.v1.ListDiskOperationsRequest\x1a\x33.yandex.cloud.compute.v1.ListDiskOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/compute/v1/disks/{disk_id}/operations\x12\x9c\x01\n\x04Move\x12(.yandex.cloud.compute.v1.MoveDiskRequest\x1a!.yandex.cloud.operation.Operation\"G\x82\xd3\xe4\x93\x02%\" /compute/v1/disks/{disk_id}:move:\x01*\xb2\xd2*\x18\n\x10MoveDiskMetadata\x12\x04\x44iskBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETDISKREQUEST = _descriptor.Descriptor(
  name='GetDiskRequest',
  full_name='yandex.cloud.compute.v1.GetDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.GetDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=323,
)


_LISTDISKSREQUEST = _descriptor.Descriptor(
  name='ListDisksRequest',
  full_name='yandex.cloud.compute.v1.ListDisksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListDisksRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListDisksRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListDisksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListDisksRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=467,
)


_LISTDISKSRESPONSE = _descriptor.Descriptor(
  name='ListDisksResponse',
  full_name='yandex.cloud.compute.v1.ListDisksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disks', full_name='yandex.cloud.compute.v1.ListDisksResponse.disks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListDisksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=559,
)


_CREATEDISKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1155,
)

_CREATEDISKREQUEST = _descriptor.Descriptor(
  name='CreateDiskRequest',
  full_name='yandex.cloud.compute.v1.CreateDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateDiskRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateDiskRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateDiskRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.type_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.zone_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.CreateDiskRequest.size', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\0264194304-28587302322176', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.image_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.snapshot_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_size', full_name='yandex.cloud.compute.v1.CreateDiskRequest.block_size', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_placement_policy', full_name='yandex.cloud.compute.v1.CreateDiskRequest.disk_placement_policy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDISKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='yandex.cloud.compute.v1.CreateDiskRequest.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=562,
  serialized_end=1165,
)


_CREATEDISKMETADATA = _descriptor.Descriptor(
  name='CreateDiskMetadata',
  full_name='yandex.cloud.compute.v1.CreateDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.CreateDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1204,
)


_UPDATEDISKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1155,
)

_UPDATEDISKREQUEST = _descriptor.Descriptor(
  name='UpdateDiskRequest',
  full_name='yandex.cloud.compute.v1.UpdateDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0254194304-4398046511104', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_placement_policy', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.disk_placement_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEDISKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1701,
)


_UPDATEDISKMETADATA = _descriptor.Descriptor(
  name='UpdateDiskMetadata',
  full_name='yandex.cloud.compute.v1.UpdateDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.UpdateDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1740,
)


_DELETEDISKREQUEST = _descriptor.Descriptor(
  name='DeleteDiskRequest',
  full_name='yandex.cloud.compute.v1.DeleteDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DeleteDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1792,
)


_DELETEDISKMETADATA = _descriptor.Descriptor(
  name='DeleteDiskMetadata',
  full_name='yandex.cloud.compute.v1.DeleteDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DeleteDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1831,
)


_LISTDISKOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListDiskOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=1953,
)


_LISTDISKOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListDiskOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2063,
)


_MOVEDISKREQUEST = _descriptor.Descriptor(
  name='MoveDiskRequest',
  full_name='yandex.cloud.compute.v1.MoveDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.MoveDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2065,
  serialized_end=2158,
)


_MOVEDISKMETADATA = _descriptor.Descriptor(
  name='MoveDiskMetadata',
  full_name='yandex.cloud.compute.v1.MoveDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.source_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.destination_folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2160,
  serialized_end=2252,
)

_LISTDISKSRESPONSE.fields_by_name['disks'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISK
_CREATEDISKREQUEST_LABELSENTRY.containing_type = _CREATEDISKREQUEST
_CREATEDISKREQUEST.fields_by_name['labels'].message_type = _CREATEDISKREQUEST_LABELSENTRY
_CREATEDISKREQUEST.fields_by_name['disk_placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISKPLACEMENTPOLICY
_CREATEDISKREQUEST.oneofs_by_name['source'].fields.append(
  _CREATEDISKREQUEST.fields_by_name['image_id'])
_CREATEDISKREQUEST.fields_by_name['image_id'].containing_oneof = _CREATEDISKREQUEST.oneofs_by_name['source']
_CREATEDISKREQUEST.oneofs_by_name['source'].fields.append(
  _CREATEDISKREQUEST.fields_by_name['snapshot_id'])
_CREATEDISKREQUEST.fields_by_name['snapshot_id'].containing_oneof = _CREATEDISKREQUEST.oneofs_by_name['source']
_UPDATEDISKREQUEST_LABELSENTRY.containing_type = _UPDATEDISKREQUEST
_UPDATEDISKREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDISKREQUEST.fields_by_name['labels'].message_type = _UPDATEDISKREQUEST_LABELSENTRY
_UPDATEDISKREQUEST.fields_by_name['disk_placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISKPLACEMENTPOLICY
_LISTDISKOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetDiskRequest'] = _GETDISKREQUEST
DESCRIPTOR.message_types_by_name['ListDisksRequest'] = _LISTDISKSREQUEST
DESCRIPTOR.message_types_by_name['ListDisksResponse'] = _LISTDISKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDiskRequest'] = _CREATEDISKREQUEST
DESCRIPTOR.message_types_by_name['CreateDiskMetadata'] = _CREATEDISKMETADATA
DESCRIPTOR.message_types_by_name['UpdateDiskRequest'] = _UPDATEDISKREQUEST
DESCRIPTOR.message_types_by_name['UpdateDiskMetadata'] = _UPDATEDISKMETADATA
DESCRIPTOR.message_types_by_name['DeleteDiskRequest'] = _DELETEDISKREQUEST
DESCRIPTOR.message_types_by_name['DeleteDiskMetadata'] = _DELETEDISKMETADATA
DESCRIPTOR.message_types_by_name['ListDiskOperationsRequest'] = _LISTDISKOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDiskOperationsResponse'] = _LISTDISKOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveDiskRequest'] = _MOVEDISKREQUEST
DESCRIPTOR.message_types_by_name['MoveDiskMetadata'] = _MOVEDISKMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDiskRequest = _reflection.GeneratedProtocolMessageType('GetDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetDiskRequest)
  })
_sym_db.RegisterMessage(GetDiskRequest)

ListDisksRequest = _reflection.GeneratedProtocolMessageType('ListDisksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDisksRequest)
  })
_sym_db.RegisterMessage(ListDisksRequest)

ListDisksResponse = _reflection.GeneratedProtocolMessageType('ListDisksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDisksResponse)
  })
_sym_db.RegisterMessage(ListDisksResponse)

CreateDiskRequest = _reflection.GeneratedProtocolMessageType('CreateDiskRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDISKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskRequest)
  })
_sym_db.RegisterMessage(CreateDiskRequest)
_sym_db.RegisterMessage(CreateDiskRequest.LabelsEntry)

CreateDiskMetadata = _reflection.GeneratedProtocolMessageType('CreateDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskMetadata)
  })
_sym_db.RegisterMessage(CreateDiskMetadata)

UpdateDiskRequest = _reflection.GeneratedProtocolMessageType('UpdateDiskRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDISKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskRequest)
  })
_sym_db.RegisterMessage(UpdateDiskRequest)
_sym_db.RegisterMessage(UpdateDiskRequest.LabelsEntry)

UpdateDiskMetadata = _reflection.GeneratedProtocolMessageType('UpdateDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskMetadata)
  })
_sym_db.RegisterMessage(UpdateDiskMetadata)

DeleteDiskRequest = _reflection.GeneratedProtocolMessageType('DeleteDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteDiskRequest)
  })
_sym_db.RegisterMessage(DeleteDiskRequest)

DeleteDiskMetadata = _reflection.GeneratedProtocolMessageType('DeleteDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteDiskMetadata)
  })
_sym_db.RegisterMessage(DeleteDiskMetadata)

ListDiskOperationsRequest = _reflection.GeneratedProtocolMessageType('ListDiskOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDiskOperationsRequest)
  })
_sym_db.RegisterMessage(ListDiskOperationsRequest)

ListDiskOperationsResponse = _reflection.GeneratedProtocolMessageType('ListDiskOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDiskOperationsResponse)
  })
_sym_db.RegisterMessage(ListDiskOperationsResponse)

MoveDiskRequest = _reflection.GeneratedProtocolMessageType('MoveDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveDiskRequest)
  })
_sym_db.RegisterMessage(MoveDiskRequest)

MoveDiskMetadata = _reflection.GeneratedProtocolMessageType('MoveDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveDiskMetadata)
  })
_sym_db.RegisterMessage(MoveDiskMetadata)


DESCRIPTOR._options = None
_GETDISKREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKSREQUEST.fields_by_name['folder_id']._options = None
_LISTDISKSREQUEST.fields_by_name['page_size']._options = None
_LISTDISKSREQUEST.fields_by_name['page_token']._options = None
_LISTDISKSREQUEST.fields_by_name['filter']._options = None
_CREATEDISKREQUEST_LABELSENTRY._options = None
_CREATEDISKREQUEST.fields_by_name['folder_id']._options = None
_CREATEDISKREQUEST.fields_by_name['name']._options = None
_CREATEDISKREQUEST.fields_by_name['description']._options = None
_CREATEDISKREQUEST.fields_by_name['labels']._options = None
_CREATEDISKREQUEST.fields_by_name['type_id']._options = None
_CREATEDISKREQUEST.fields_by_name['zone_id']._options = None
_CREATEDISKREQUEST.fields_by_name['size']._options = None
_CREATEDISKREQUEST.fields_by_name['image_id']._options = None
_CREATEDISKREQUEST.fields_by_name['snapshot_id']._options = None
_UPDATEDISKREQUEST_LABELSENTRY._options = None
_UPDATEDISKREQUEST.fields_by_name['disk_id']._options = None
_UPDATEDISKREQUEST.fields_by_name['name']._options = None
_UPDATEDISKREQUEST.fields_by_name['description']._options = None
_UPDATEDISKREQUEST.fields_by_name['labels']._options = None
_UPDATEDISKREQUEST.fields_by_name['size']._options = None
_DELETEDISKREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_MOVEDISKREQUEST.fields_by_name['disk_id']._options = None
_MOVEDISKREQUEST.fields_by_name['destination_folder_id']._options = None

_DISKSERVICE = _descriptor.ServiceDescriptor(
  name='DiskService',
  full_name='yandex.cloud.compute.v1.DiskService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2255,
  serialized_end=3321,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.DiskService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDISKREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISK,
    serialized_options=b'\202\323\344\223\002\035\022\033/compute/v1/disks/{disk_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.DiskService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDISKSREQUEST,
    output_type=_LISTDISKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/compute/v1/disks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.DiskService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/compute/v1/disks:\001*\262\322*\032\n\022CreateDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.DiskService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/compute/v1/disks/{disk_id}:\001*\262\322*\032\n\022UpdateDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.DiskService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/compute/v1/disks/{disk_id}\262\322*+\n\022DeleteDiskMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.DiskService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTDISKOPERATIONSREQUEST,
    output_type=_LISTDISKOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/compute/v1/disks/{disk_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.compute.v1.DiskService.Move',
    index=6,
    containing_service=None,
    input_type=_MOVEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /compute/v1/disks/{disk_id}:move:\001*\262\322*\030\n\020MoveDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISKSERVICE)

DESCRIPTOR.services_by_name['DiskService'] = _DISKSERVICE

# @@protoc_insertion_point(module_scope)
