# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.certificatemanager.v1 import certificate_pb2 as yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/certificatemanager/v1/certificate_service.proto',
  package='yandex.cloud.certificatemanager.v1',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<yandex/cloud/certificatemanager/v1/certificate_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x34yandex/cloud/certificatemanager/v1/certificate.proto\x1a yandex/cloud/access/access.proto\"\x80\x01\n\x15GetCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"\xbb\x01\n\x17ListCertificatesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x41\n\x04view\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"z\n\x18ListCertificatesResponse\x12\x45\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32/.yandex.cloud.certificatemanager.v1.Certificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x13ListVersionsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x14ListVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32+.yandex.cloud.certificatemanager.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc2\x03\n\x18\x43reateCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x06 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12%\n\x0bprivate_key\x18\x07 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08\x31-524288\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19\x43reateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xf4\x03\n\x18UpdateCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x05 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12 \n\x0b\x63\x65rtificate\x18\x06 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x07 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12!\n\x0bprivate_key\x18\x08 \x01(\tB\x0c\x8a\xc8\x31\x08<=524288\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xbf\x03\n\x1cRequestNewCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x9d\x01\n\x06labels\x18\x04 \x03(\x0b\x32L.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x0f\n\x07\x64omains\x18\x05 \x03(\t\x12I\n\x0e\x63hallenge_type\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x1dRequestNewCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x86\x01\n ListCertificateOperationsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListCertificateOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*&\n\x0f\x43\x65rtificateView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xca\x12\n\x12\x43\x65rtificateService\x12\xb0\x01\n\x03Get\x12\x39.yandex.cloud.certificatemanager.v1.GetCertificateRequest\x1a/.yandex.cloud.certificatemanager.v1.Certificate\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/certificate-manager/v1/certificates/{certificate_id}\x12\xaf\x01\n\x04List\x12;.yandex.cloud.certificatemanager.v1.ListCertificatesRequest\x1a<.yandex.cloud.certificatemanager.v1.ListCertificatesResponse\",\x82\xd3\xe4\x93\x02&\x12$/certificate-manager/v1/certificates\x12\xc9\x01\n\x0cListVersions\x12\x37.yandex.cloud.certificatemanager.v1.ListVersionsRequest\x1a\x38.yandex.cloud.certificatemanager.v1.ListVersionsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/certificate-manager/v1/certificates/{certificate_id}/versions\x12\xc6\x01\n\x06\x43reate\x12<.yandex.cloud.certificatemanager.v1.CreateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02)\"$/certificate-manager/v1/certificates:\x01*\xb2\xd2*(\n\x19\x43reateCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xd7\x01\n\x06Update\x12<.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"l\x82\xd3\xe4\x93\x02:25/certificate-manager/v1/certificates/{certificate_id}:\x01*\xb2\xd2*(\n\x19UpdateCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xd4\x01\n\x06\x44\x65lete\x12<.yandex.cloud.certificatemanager.v1.DeleteCertificateRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x37*5/certificate-manager/v1/certificates/{certificate_id}\xb2\xd2*(\n\x19\x44\x65leteCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xdd\x01\n\nRequestNew\x12@.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest\x1a!.yandex.cloud.operation.Operation\"j\x82\xd3\xe4\x93\x02\x34\"//certificate-manager/v1/certificates/requestNew:\x01*\xb2\xd2*,\n\x1dRequestNewCertificateMetadata\x12\x0b\x43\x65rtificate\x12\xe7\x01\n\x0eListOperations\x12\x44.yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest\x1a\x45.yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}/operations\x12\xc4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/certificate-manager/v1/certificates/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\x82\xd3\xe4\x93\x02I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\x82\xd3\xe4\x93\x02L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyB\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,])

_CERTIFICATEVIEW = _descriptor.EnumDescriptor(
  name='CertificateView',
  full_name='yandex.cloud.certificatemanager.v1.CertificateView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2979,
  serialized_end=3017,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVIEW)

CertificateView = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEVIEW)
BASIC = 0
FULL = 1



_GETCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='GetCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.certificatemanager.v1.GetCertificateRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=486,
)


_LISTCERTIFICATESREQUEST = _descriptor.Descriptor(
  name='ListCertificatesRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesRequest.view', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=676,
)


_LISTCERTIFICATESRESPONSE = _descriptor.Descriptor(
  name='ListCertificatesResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificatesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=800,
)


_LISTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListVersionsRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListVersionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=923,
)


_LISTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListVersionsResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListVersionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1035,
)


_CREATECERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_CREATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.certificate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.chain', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=2097152', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateRequest.private_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0101-524288', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1488,
)


_CREATECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='CreateCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.CreateCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.CreateCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1541,
)


_UPDATECERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_UPDATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='UpdateCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.certificate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\007<=32768', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.chain', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\t<=2097152', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.private_key', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\010<=524288', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=2044,
)


_UPDATECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='UpdateCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2097,
)


_DELETECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='DeleteCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2099,
  serialized_end=2163,
)


_DELETECERTIFICATEMETADATA = _descriptor.Descriptor(
  name='DeleteCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2165,
  serialized_end=2216,
)


_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1488,
)

_REQUESTNEWCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='RequestNewCertificateRequest',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domains', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.domains', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='challenge_type', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.challenge_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=2666,
)


_REQUESTNEWCERTIFICATEMETADATA = _descriptor.Descriptor(
  name='RequestNewCertificateMetadata',
  full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2668,
  serialized_end=2723,
)


_LISTCERTIFICATEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListCertificateOperationsRequest',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.certificate_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2860,
)


_LISTCERTIFICATEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListCertificateOperationsResponse',
  full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2862,
  serialized_end=2977,
)

_GETCERTIFICATEREQUEST.fields_by_name['view'].enum_type = _CERTIFICATEVIEW
_LISTCERTIFICATESREQUEST.fields_by_name['view'].enum_type = _CERTIFICATEVIEW
_LISTCERTIFICATESRESPONSE.fields_by_name['certificates'].message_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CERTIFICATE
_LISTVERSIONSRESPONSE.fields_by_name['versions'].message_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._VERSION
_CREATECERTIFICATEREQUEST_LABELSENTRY.containing_type = _CREATECERTIFICATEREQUEST
_CREATECERTIFICATEREQUEST.fields_by_name['labels'].message_type = _CREATECERTIFICATEREQUEST_LABELSENTRY
_UPDATECERTIFICATEREQUEST_LABELSENTRY.containing_type = _UPDATECERTIFICATEREQUEST
_UPDATECERTIFICATEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECERTIFICATEREQUEST.fields_by_name['labels'].message_type = _UPDATECERTIFICATEREQUEST_LABELSENTRY
_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY.containing_type = _REQUESTNEWCERTIFICATEREQUEST
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels'].message_type = _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['challenge_type'].enum_type = yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CHALLENGETYPE
_LISTCERTIFICATEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetCertificateRequest'] = _GETCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['ListCertificatesRequest'] = _LISTCERTIFICATESREQUEST
DESCRIPTOR.message_types_by_name['ListCertificatesResponse'] = _LISTCERTIFICATESRESPONSE
DESCRIPTOR.message_types_by_name['ListVersionsRequest'] = _LISTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListVersionsResponse'] = _LISTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCertificateRequest'] = _CREATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateCertificateMetadata'] = _CREATECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['UpdateCertificateRequest'] = _UPDATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['UpdateCertificateMetadata'] = _UPDATECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['DeleteCertificateRequest'] = _DELETECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['DeleteCertificateMetadata'] = _DELETECERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['RequestNewCertificateRequest'] = _REQUESTNEWCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['RequestNewCertificateMetadata'] = _REQUESTNEWCERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['ListCertificateOperationsRequest'] = _LISTCERTIFICATEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCertificateOperationsResponse'] = _LISTCERTIFICATEOPERATIONSRESPONSE
DESCRIPTOR.enum_types_by_name['CertificateView'] = _CERTIFICATEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCertificateRequest = _reflection.GeneratedProtocolMessageType('GetCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.GetCertificateRequest)
  })
_sym_db.RegisterMessage(GetCertificateRequest)

ListCertificatesRequest = _reflection.GeneratedProtocolMessageType('ListCertificatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATESREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificatesRequest)
  })
_sym_db.RegisterMessage(ListCertificatesRequest)

ListCertificatesResponse = _reflection.GeneratedProtocolMessageType('ListCertificatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATESRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificatesResponse)
  })
_sym_db.RegisterMessage(ListCertificatesResponse)

ListVersionsRequest = _reflection.GeneratedProtocolMessageType('ListVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVERSIONSREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListVersionsRequest)
  })
_sym_db.RegisterMessage(ListVersionsRequest)

ListVersionsResponse = _reflection.GeneratedProtocolMessageType('ListVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVERSIONSRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListVersionsResponse)
  })
_sym_db.RegisterMessage(ListVersionsResponse)

CreateCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateRequest)
  })
_sym_db.RegisterMessage(CreateCertificateRequest)
_sym_db.RegisterMessage(CreateCertificateRequest.LabelsEntry)

CreateCertificateMetadata = _reflection.GeneratedProtocolMessageType('CreateCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.CreateCertificateMetadata)
  })
_sym_db.RegisterMessage(CreateCertificateMetadata)

UpdateCertificateRequest = _reflection.GeneratedProtocolMessageType('UpdateCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateRequest)
  })
_sym_db.RegisterMessage(UpdateCertificateRequest)
_sym_db.RegisterMessage(UpdateCertificateRequest.LabelsEntry)

UpdateCertificateMetadata = _reflection.GeneratedProtocolMessageType('UpdateCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.UpdateCertificateMetadata)
  })
_sym_db.RegisterMessage(UpdateCertificateMetadata)

DeleteCertificateRequest = _reflection.GeneratedProtocolMessageType('DeleteCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.DeleteCertificateRequest)
  })
_sym_db.RegisterMessage(DeleteCertificateRequest)

DeleteCertificateMetadata = _reflection.GeneratedProtocolMessageType('DeleteCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.DeleteCertificateMetadata)
  })
_sym_db.RegisterMessage(DeleteCertificateMetadata)

RequestNewCertificateRequest = _reflection.GeneratedProtocolMessageType('RequestNewCertificateRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _REQUESTNEWCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest)
  })
_sym_db.RegisterMessage(RequestNewCertificateRequest)
_sym_db.RegisterMessage(RequestNewCertificateRequest.LabelsEntry)

RequestNewCertificateMetadata = _reflection.GeneratedProtocolMessageType('RequestNewCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNEWCERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.RequestNewCertificateMetadata)
  })
_sym_db.RegisterMessage(RequestNewCertificateMetadata)

ListCertificateOperationsRequest = _reflection.GeneratedProtocolMessageType('ListCertificateOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATEOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest)
  })
_sym_db.RegisterMessage(ListCertificateOperationsRequest)

ListCertificateOperationsResponse = _reflection.GeneratedProtocolMessageType('ListCertificateOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERTIFICATEOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.certificatemanager.v1.certificate_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse)
  })
_sym_db.RegisterMessage(ListCertificateOperationsResponse)


DESCRIPTOR._options = None
_GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['page_size']._options = None
_LISTCERTIFICATESREQUEST.fields_by_name['page_token']._options = None
_LISTVERSIONSREQUEST.fields_by_name['certificate_id']._options = None
_LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
_LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
_CREATECERTIFICATEREQUEST_LABELSENTRY._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['name']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['description']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
_CREATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
_UPDATECERTIFICATEREQUEST_LABELSENTRY._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['name']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['description']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
_UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
_DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._options = None
_REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_CERTIFICATESERVICE = _descriptor.ServiceDescriptor(
  name='CertificateService',
  full_name='yandex.cloud.certificatemanager.v1.CertificateService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3020,
  serialized_end=5398,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2._CERTIFICATE,
    serialized_options=b'\202\323\344\223\0027\0225/certificate-manager/v1/certificates/{certificate_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCERTIFICATESREQUEST,
    output_type=_LISTCERTIFICATESRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/certificate-manager/v1/certificates',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVersions',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListVersions',
    index=2,
    containing_service=None,
    input_type=_LISTVERSIONSREQUEST,
    output_type=_LISTVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/certificate-manager/v1/certificates/{certificate_id}/versions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Create',
    index=3,
    containing_service=None,
    input_type=_CREATECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)\"$/certificate-manager/v1/certificates:\001*\262\322*(\n\031CreateCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002:25/certificate-manager/v1/certificates/{certificate_id}:\001*\262\322*(\n\031UpdateCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.Delete',
    index=5,
    containing_service=None,
    input_type=_DELETECERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0027*5/certificate-manager/v1/certificates/{certificate_id}\262\322*(\n\031DeleteCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestNew',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.RequestNew',
    index=6,
    containing_service=None,
    input_type=_REQUESTNEWCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0024\"//certificate-manager/v1/certificates/requestNew:\001*\262\322*,\n\035RequestNewCertificateMetadata\022\013Certificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTCERTIFICATEOPERATIONSREQUEST,
    output_type=_LISTCERTIFICATEOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.ListAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002G\022E/certificate-manager/v1/certificates/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.SetAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.certificatemanager.v1.CertificateService.UpdateAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CERTIFICATESERVICE)

DESCRIPTOR.services_by_name['CertificateService'] = _CERTIFICATESERVICE

# @@protoc_insertion_point(module_scope)
