# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mongo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/mongo.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/datatransfer/v1/endpoint/mongo.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x84\x01\n\x0eOnPremiseMongo\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSMode\x12\x13\n\x0breplica_set\x18\x05 \x01(\t\"\xee\x01\n\x16MongoConnectionOptions\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongoH\x00\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x13\n\x0b\x61uth_source\x18\x05 \x01(\tB\t\n\x07\x61\x64\x64ress\"|\n\x0fMongoConnection\x12[\n\x12\x63onnection_options\x18\x03 \x01(\x0b\x32=.yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptionsH\x00\x42\x0c\n\nconnection\"A\n\x0fMongoCollection\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"\xca\x02\n\x0bMongoSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x0b \x03(\t\x12K\n\x0b\x63ollections\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12T\n\x14\x65xcluded_collections\x18\x07 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12 \n\x18secondary_preferred_mode\x18\x08 \x01(\x08\"\xe5\x01\n\x0bMongoTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x08 \x03(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicyB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])




_ONPREMISEMONGO = _descriptor.Descriptor(
  name='OnPremiseMongo',
  full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.hosts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.port', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.tls_mode', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replica_set', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo.replica_set', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=277,
)


_MONGOCONNECTIONOPTIONS = _descriptor.Descriptor(
  name='MongoConnectionOptions',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdb_cluster_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.mdb_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_premise', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.on_premise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.password', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_source', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.auth_source', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=518,
)


_MONGOCONNECTION = _descriptor.Descriptor(
  name='MongoConnection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_options', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection.connection_options', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoConnection.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=520,
  serialized_end=644,
)


_MONGOCOLLECTION = _descriptor.Descriptor(
  name='MongoCollection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection.database_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoCollection.collection_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=711,
)


_MONGOSOURCE = _descriptor.Descriptor(
  name='MongoSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.security_groups', index=2,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collections', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.collections', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_collections', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.excluded_collections', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_preferred_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoSource.secondary_preferred_mode', index=5,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=1044,
)


_MONGOTARGET = _descriptor.Descriptor(
  name='MongoTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.subnet_id', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.security_groups', index=2,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.database', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.MongoTarget.cleanup_policy', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1276,
)

_ONPREMISEMONGO.fields_by_name['tls_mode'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._TLSMODE
_MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'].message_type = _ONPREMISEMONGO
_MONGOCONNECTIONOPTIONS.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_MONGOCONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _MONGOCONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'])
_MONGOCONNECTIONOPTIONS.fields_by_name['mdb_cluster_id'].containing_oneof = _MONGOCONNECTIONOPTIONS.oneofs_by_name['address']
_MONGOCONNECTIONOPTIONS.oneofs_by_name['address'].fields.append(
  _MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'])
_MONGOCONNECTIONOPTIONS.fields_by_name['on_premise'].containing_oneof = _MONGOCONNECTIONOPTIONS.oneofs_by_name['address']
_MONGOCONNECTION.fields_by_name['connection_options'].message_type = _MONGOCONNECTIONOPTIONS
_MONGOCONNECTION.oneofs_by_name['connection'].fields.append(
  _MONGOCONNECTION.fields_by_name['connection_options'])
_MONGOCONNECTION.fields_by_name['connection_options'].containing_oneof = _MONGOCONNECTION.oneofs_by_name['connection']
_MONGOSOURCE.fields_by_name['connection'].message_type = _MONGOCONNECTION
_MONGOSOURCE.fields_by_name['collections'].message_type = _MONGOCOLLECTION
_MONGOSOURCE.fields_by_name['excluded_collections'].message_type = _MONGOCOLLECTION
_MONGOTARGET.fields_by_name['connection'].message_type = _MONGOCONNECTION
_MONGOTARGET.fields_by_name['cleanup_policy'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._CLEANUPPOLICY
DESCRIPTOR.message_types_by_name['OnPremiseMongo'] = _ONPREMISEMONGO
DESCRIPTOR.message_types_by_name['MongoConnectionOptions'] = _MONGOCONNECTIONOPTIONS
DESCRIPTOR.message_types_by_name['MongoConnection'] = _MONGOCONNECTION
DESCRIPTOR.message_types_by_name['MongoCollection'] = _MONGOCOLLECTION
DESCRIPTOR.message_types_by_name['MongoSource'] = _MONGOSOURCE
DESCRIPTOR.message_types_by_name['MongoTarget'] = _MONGOTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OnPremiseMongo = _reflection.GeneratedProtocolMessageType('OnPremiseMongo', (_message.Message,), {
  'DESCRIPTOR' : _ONPREMISEMONGO,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongo)
  })
_sym_db.RegisterMessage(OnPremiseMongo)

MongoConnectionOptions = _reflection.GeneratedProtocolMessageType('MongoConnectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCONNECTIONOPTIONS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptions)
  })
_sym_db.RegisterMessage(MongoConnectionOptions)

MongoConnection = _reflection.GeneratedProtocolMessageType('MongoConnection', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCONNECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoConnection)
  })
_sym_db.RegisterMessage(MongoConnection)

MongoCollection = _reflection.GeneratedProtocolMessageType('MongoCollection', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCOLLECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoCollection)
  })
_sym_db.RegisterMessage(MongoCollection)

MongoSource = _reflection.GeneratedProtocolMessageType('MongoSource', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoSource)
  })
_sym_db.RegisterMessage(MongoSource)

MongoTarget = _reflection.GeneratedProtocolMessageType('MongoTarget', (_message.Message,), {
  'DESCRIPTOR' : _MONGOTARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MongoTarget)
  })
_sym_db.RegisterMessage(MongoTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
